==> ms-users-12.1.1.tgz: package/lib/actions/regenerate-token.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  selectChallenge
} = require('../utils/challenges/challenge');

const {
  TOKEN_METADATA_FIELD_CONTEXT
} = require('../constants');
/**
 * @api {amqp} <prefix>.regenerate-token Regenerate expired token
 * @apiVersion 1.0.0
 * @apiName RegenerateToken
 * @apiGroup Users
 *
 * @apiDescription This method allowes to regenerate expired token. It takes `uid`
 * or `id` and `action` as token identificator. Currently only phone challenge supported.
 *
 * @apiSchema {jsonschema=../../schemas/regenerate-token.json} apiParam
 */


module.exports = async function regenerateToken({
  params
}) {
  const {
    action,
    challengeType,
    id,
    uid
  } = params;
  const {
    tokenManager
  } = this;
  const args = uid ? {
    uid
  } : {
    action,
    id
  };
  await tokenManager.regenerate(args);
  const token = await tokenManager.info(args);
  let context;

  if (token.metadata && token.metadata[TOKEN_METADATA_FIELD_CONTEXT]) {
    context = token.metadata[TOKEN_METADATA_FIELD_CONTEXT];
  } else {
    context = Object.create(null);
  }

  const challenge = selectChallenge(challengeType, token.action, _objectSpread({}, context, {
    token
  }));
  const challengeResponse = await challenge.call(this, token.id);
  const response = {
    regenerated: true
  };
  const tokenUid = challengeResponse.context.token.uid;

  if (uid) {
    response.uid = tokenUid;
  }

  return response;
};

module.exports.transports = [require('@microfleet/core').ActionTransport.amqp];

==> ms-users-14.13.0.tgz: package/lib/actions/regenerate-token.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  selectChallenge
} = require('../utils/challenges/challenge');

const {
  TOKEN_METADATA_FIELD_CONTEXT
} = require('../constants');
/**
 * @api {amqp} <prefix>.regenerate-token Regenerate expired token
 * @apiVersion 1.0.0
 * @apiName RegenerateToken
 * @apiGroup Users
 *
 * @apiDescription This method allowes to regenerate expired token. It takes `uid`
 * or `id` and `action` as token identificator. Currently only phone challenge supported.
 *
 * @apiSchema {jsonschema=../../schemas/regenerate-token.json} apiParam
 */


module.exports = async function regenerateToken({
  params
}) {
  const {
    action,
    challengeType,
    id,
    uid
  } = params;
  const {
    tokenManager
  } = this;
  const args = uid ? {
    uid
  } : {
    action,
    id
  };
  await tokenManager.regenerate(args);
  const token = await tokenManager.info(args);
  let context;

  if (token.metadata && token.metadata[TOKEN_METADATA_FIELD_CONTEXT]) {
    context = token.metadata[TOKEN_METADATA_FIELD_CONTEXT];
  } else {
    context = Object.create(null);
  }

  const challenge = selectChallenge(challengeType, token.action, _objectSpread(_objectSpread({}, context), {}, {
    token
  }));
  const challengeResponse = await challenge.call(this, token.id);
  const response = {
    regenerated: true
  };
  const tokenUid = challengeResponse.context.token.uid;

  if (uid) {
    response.uid = tokenUid;
  }

  return response;
};

module.exports.transports = [require('@microfleet/core').ActionTransport.amqp];
